==> dpws-model-1.1.0-sources.jar: org/somda/sdc/dpws/soap/wsdiscovery/model/HelloType.java <==

package org.somda.sdc.dpws.soap.wsdiscovery.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlList;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.somda.sdc.dpws.soap.wsaddressing.model.EndpointReferenceType;
import org.w3c.dom.Element;


/**
 * <p>Java class for HelloType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HelloType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2005/08/addressing}EndpointReference"/&gt;
 *         &lt;element ref="{http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01}Types" minOccurs="0"/&gt;
 *         &lt;element ref="{http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01}Scopes" minOccurs="0"/&gt;
 *         &lt;element ref="{http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01}XAddrs" minOccurs="0"/&gt;
 *         &lt;element ref="{http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01}MetadataVersion"/&gt;
 *         &lt;any processContents='lax' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HelloType", namespace = "http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01", propOrder = {
    "endpointReference",
    "types",
    "scopes",
    "xAddrs",
    "metadataVersion",
    "any"
})
public class HelloType implements ToString2
{

    @XmlElement(name = "EndpointReference", namespace = "http://www.w3.org/2005/08/addressing", required = true)
    protected EndpointReferenceType endpointReference;
    @XmlList
    @XmlElement(name = "Types", namespace = "http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01")
    protected List<QName> types;
    @XmlElement(name = "Scopes", namespace = "http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01")
    protected ScopesType scopes;
    @XmlList
    @XmlElement(name = "XAddrs", namespace = "http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01")
    protected List<String> xAddrs;
    @XmlElement(name = "MetadataVersion", namespace = "http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01")
    @XmlSchemaType(name = "unsignedInt")
    protected long metadataVersion;
    @XmlAnyElement(lax = true)
    protected List<Object> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Ruft den Wert der endpointReference-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link EndpointReferenceType }
     *     
     */
    public EndpointReferenceType getEndpointReference() {
        return endpointReference;
    }

    /**
     * Legt den Wert der endpointReference-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link EndpointReferenceType }
     *     
     */
    public void setEndpointReference(EndpointReferenceType value) {
        this.endpointReference = value;
    }

    /**
     * Gets the value of the types property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the types property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTypes().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link QName }
     * 
     * 
     */
    public List<QName> getTypes() {
        if (types == null) {
            types = new ArrayList<QName>();
        }
        return this.types;
    }

    /**
     * Ruft den Wert der scopes-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ScopesType }
     *     
     */
    public ScopesType getScopes() {
        return scopes;
    }

    /**
     * Legt den Wert der scopes-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ScopesType }
     *     
     */
    public void setScopes(ScopesType value) {
        this.scopes = value;
    }

    /**
     * Gets the value of the xAddrs property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the xAddrs property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getXAddrs().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    public List<String> getXAddrs() {
        if (xAddrs == null) {
            xAddrs = new ArrayList<String>();
        }
        return this.xAddrs;
    }

    /**
     * Ruft den Wert der metadataVersion-Eigenschaft ab.
     * 
     */
    public long getMetadataVersion() {
        return metadataVersion;
    }

    /**
     * Legt den Wert der metadataVersion-Eigenschaft fest.
     * 
     */
    public void setMetadataVersion(long value) {
        this.metadataVersion = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * {@link Object }
     * 
     * 
     */
    public List<Object> getAny() {
        if (any == null) {
            any = new ArrayList<Object>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setTypes(List<QName> value) {
        this.types = null;
        if (value!= null) {
            List<QName> draftl = this.getTypes();
            draftl.addAll(value);
        }
    }

    public void setXAddrs(List<String> value) {
        this.xAddrs = null;
        if (value!= null) {
            List<String> draftl = this.getXAddrs();
            draftl.addAll(value);
        }
    }

    public void setAny(List<Object> value) {
        this.any = null;
        if (value!= null) {
            List<Object> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final HelloType that = ((HelloType) object);
        {
            EndpointReferenceType leftEndpointReference;
            leftEndpointReference = this.getEndpointReference();
            EndpointReferenceType rightEndpointReference;
            rightEndpointReference = that.getEndpointReference();
            if (this.endpointReference!= null) {
                if (that.endpointReference!= null) {
                    if (!leftEndpointReference.equals(rightEndpointReference)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.endpointReference!= null) {
                    return false;
                }
            }
        }
        {
            List<QName> leftTypes;
            leftTypes = (((this.types!= null)&&(!this.types.isEmpty()))?this.getTypes():null);
            List<QName> rightTypes;
            rightTypes = (((that.types!= null)&&(!that.types.isEmpty()))?that.getTypes():null);
            if ((this.types!= null)&&(!this.types.isEmpty())) {
                if ((that.types!= null)&&(!that.types.isEmpty())) {
                    if (!leftTypes.equals(rightTypes)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.types!= null)&&(!that.types.isEmpty())) {
                    return false;
                }
            }
        }
        {
            ScopesType leftScopes;
            leftScopes = this.getScopes();
            ScopesType rightScopes;
            rightScopes = that.getScopes();
            if (this.scopes!= null) {
                if (that.scopes!= null) {
                    if (!leftScopes.equals(rightScopes)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.scopes!= null) {
                    return false;
                }
            }
        }
        {
            List<String> leftXAddrs;
            leftXAddrs = (((this.xAddrs!= null)&&(!this.xAddrs.isEmpty()))?this.getXAddrs():null);
            List<String> rightXAddrs;
            rightXAddrs = (((that.xAddrs!= null)&&(!that.xAddrs.isEmpty()))?that.getXAddrs():null);
            if ((this.xAddrs!= null)&&(!this.xAddrs.isEmpty())) {
                if ((that.xAddrs!= null)&&(!that.xAddrs.isEmpty())) {
                    if (!leftXAddrs.equals(rightXAddrs)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.xAddrs!= null)&&(!that.xAddrs.isEmpty())) {
                    return false;
                }
            }
        }
        {
            long leftMetadataVersion;
            leftMetadataVersion = this.getMetadataVersion();
            long rightMetadataVersion;
            rightMetadataVersion = that.getMetadataVersion();
            if (leftMetadataVersion!= rightMetadataVersion) {
                return false;
            }
        }
        {
            List<Object> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Object> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            EndpointReferenceType theEndpointReference;
            theEndpointReference = this.getEndpointReference();
            if (this.endpointReference!= null) {
                currentHashCode += theEndpointReference.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<QName> theTypes;
            theTypes = (((this.types!= null)&&(!this.types.isEmpty()))?this.getTypes():null);
            if ((this.types!= null)&&(!this.types.isEmpty())) {
                currentHashCode += theTypes.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            ScopesType theScopes;
            theScopes = this.getScopes();
            if (this.scopes!= null) {
                currentHashCode += theScopes.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<String> theXAddrs;
            theXAddrs = (((this.xAddrs!= null)&&(!this.xAddrs.isEmpty()))?this.getXAddrs():null);
            if ((this.xAddrs!= null)&&(!this.xAddrs.isEmpty())) {
                currentHashCode += theXAddrs.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            long theMetadataVersion;
            theMetadataVersion = this.getMetadataVersion();
            currentHashCode += ((int)(theMetadataVersion^(theMetadataVersion >>> 32)));
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            EndpointReferenceType theEndpointReference;
            theEndpointReference = this.getEndpointReference();
            strategy.appendField(locator, this, "endpointReference", buffer, theEndpointReference, (this.endpointReference!= null));
        }
        {
            List<QName> theTypes;
            theTypes = (((this.types!= null)&&(!this.types.isEmpty()))?this.getTypes():null);
            strategy.appendField(locator, this, "types", buffer, theTypes, ((this.types!= null)&&(!this.types.isEmpty())));
        }
        {
            ScopesType theScopes;
            theScopes = this.getScopes();
            strategy.appendField(locator, this, "scopes", buffer, theScopes, (this.scopes!= null));
        }
        {
            List<String> theXAddrs;
            theXAddrs = (((this.xAddrs!= null)&&(!this.xAddrs.isEmpty()))?this.getXAddrs():null);
            strategy.appendField(locator, this, "xAddrs", buffer, theXAddrs, ((this.xAddrs!= null)&&(!this.xAddrs.isEmpty())));
        }
        {
            long theMetadataVersion;
            theMetadataVersion = this.getMetadataVersion();
            strategy.appendField(locator, this, "metadataVersion", buffer, theMetadataVersion, true);
        }
        {
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

}

==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/soap/wsdiscovery/model/HelloType.java <==

package org.somda.sdc.dpws.soap.wsdiscovery.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlList;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.somda.sdc.dpws.soap.wsaddressing.model.EndpointReferenceType;
import org.w3c.dom.Element;


/**
 * <p>Java class for HelloType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HelloType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2005/08/addressing}EndpointReference"/&gt;
 *         &lt;element ref="{http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01}Types" minOccurs="0"/&gt;
 *         &lt;element ref="{http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01}Scopes" minOccurs="0"/&gt;
 *         &lt;element ref="{http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01}XAddrs" minOccurs="0"/&gt;
 *         &lt;element ref="{http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01}MetadataVersion"/&gt;
 *         &lt;any processContents='lax' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HelloType", namespace = "http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01", propOrder = {
    "endpointReference",
    "types",
    "scopes",
    "xAddrs",
    "metadataVersion",
    "any"
})
public class HelloType implements ToString2
{

    @XmlElement(name = "EndpointReference", namespace = "http://www.w3.org/2005/08/addressing", required = true)
    protected EndpointReferenceType endpointReference;
    @XmlList
    @XmlElement(name = "Types", namespace = "http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01")
    protected List<QName> types;
    @XmlElement(name = "Scopes", namespace = "http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01")
    protected ScopesType scopes;
    @XmlList
    @XmlElement(name = "XAddrs", namespace = "http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01")
    protected List<String> xAddrs;
    @XmlElement(name = "MetadataVersion", namespace = "http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01")
    @XmlSchemaType(name = "unsignedInt")
    protected long metadataVersion;
    @XmlAnyElement(lax = true)
    protected List<Object> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the endpointReference property.
     * 
     * @return
     *     possible object is
     *     {@link EndpointReferenceType }
     *     
     */
    public EndpointReferenceType getEndpointReference() {
        return endpointReference;
    }

    /**
     * Sets the value of the endpointReference property.
     * 
     * @param value
     *     allowed object is
     *     {@link EndpointReferenceType }
     *     
     */
    public void setEndpointReference(EndpointReferenceType value) {
        this.endpointReference = value;
    }

    /**
     * Gets the value of the types property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the types property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTypes().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link QName }
     * 
     * 
     */
    public List<QName> getTypes() {
        if (types == null) {
            types = new ArrayList<QName>();
        }
        return this.types;
    }

    /**
     * Gets the value of the scopes property.
     * 
     * @return
     *     possible object is
     *     {@link ScopesType }
     *     
     */
    public ScopesType getScopes() {
        return scopes;
    }

    /**
     * Sets the value of the scopes property.
     * 
     * @param value
     *     allowed object is
     *     {@link ScopesType }
     *     
     */
    public void setScopes(ScopesType value) {
        this.scopes = value;
    }

    /**
     * Gets the value of the xAddrs property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the xAddrs property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getXAddrs().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    public List<String> getXAddrs() {
        if (xAddrs == null) {
            xAddrs = new ArrayList<String>();
        }
        return this.xAddrs;
    }

    /**
     * Gets the value of the metadataVersion property.
     * 
     */
    public long getMetadataVersion() {
        return metadataVersion;
    }

    /**
     * Sets the value of the metadataVersion property.
     * 
     */
    public void setMetadataVersion(long value) {
        this.metadataVersion = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * {@link Object }
     * 
     * 
     */
    public List<Object> getAny() {
        if (any == null) {
            any = new ArrayList<Object>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setTypes(List<QName> value) {
        this.types = null;
        if (value!= null) {
            List<QName> draftl = this.getTypes();
            draftl.addAll(value);
        }
    }

    public void setXAddrs(List<String> value) {
        this.xAddrs = null;
        if (value!= null) {
            List<String> draftl = this.getXAddrs();
            draftl.addAll(value);
        }
    }

    public void setAny(List<Object> value) {
        this.any = null;
        if (value!= null) {
            List<Object> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final HelloType that = ((HelloType) object);
        {
            EndpointReferenceType leftEndpointReference;
            leftEndpointReference = this.getEndpointReference();
            EndpointReferenceType rightEndpointReference;
            rightEndpointReference = that.getEndpointReference();
            if (this.endpointReference!= null) {
                if (that.endpointReference!= null) {
                    if (!leftEndpointReference.equals(rightEndpointReference)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.endpointReference!= null) {
                    return false;
                }
            }
        }
        {
            List<QName> leftTypes;
            leftTypes = (((this.types!= null)&&(!this.types.isEmpty()))?this.getTypes():null);
            List<QName> rightTypes;
            rightTypes = (((that.types!= null)&&(!that.types.isEmpty()))?that.getTypes():null);
            if ((this.types!= null)&&(!this.types.isEmpty())) {
                if ((that.types!= null)&&(!that.types.isEmpty())) {
                    if (!leftTypes.equals(rightTypes)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.types!= null)&&(!that.types.isEmpty())) {
                    return false;
                }
            }
        }
        {
            ScopesType leftScopes;
            leftScopes = this.getScopes();
            ScopesType rightScopes;
            rightScopes = that.getScopes();
            if (this.scopes!= null) {
                if (that.scopes!= null) {
                    if (!leftScopes.equals(rightScopes)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.scopes!= null) {
                    return false;
                }
            }
        }
        {
            List<String> leftXAddrs;
            leftXAddrs = (((this.xAddrs!= null)&&(!this.xAddrs.isEmpty()))?this.getXAddrs():null);
            List<String> rightXAddrs;
            rightXAddrs = (((that.xAddrs!= null)&&(!that.xAddrs.isEmpty()))?that.getXAddrs():null);
            if ((this.xAddrs!= null)&&(!this.xAddrs.isEmpty())) {
                if ((that.xAddrs!= null)&&(!that.xAddrs.isEmpty())) {
                    if (!leftXAddrs.equals(rightXAddrs)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.xAddrs!= null)&&(!that.xAddrs.isEmpty())) {
                    return false;
                }
            }
        }
        {
            long leftMetadataVersion;
            leftMetadataVersion = this.getMetadataVersion();
            long rightMetadataVersion;
            rightMetadataVersion = that.getMetadataVersion();
            if (leftMetadataVersion!= rightMetadataVersion) {
                return false;
            }
        }
        {
            List<Object> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Object> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            EndpointReferenceType theEndpointReference;
            theEndpointReference = this.getEndpointReference();
            if (this.endpointReference!= null) {
                currentHashCode += theEndpointReference.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<QName> theTypes;
            theTypes = (((this.types!= null)&&(!this.types.isEmpty()))?this.getTypes():null);
            if ((this.types!= null)&&(!this.types.isEmpty())) {
                currentHashCode += theTypes.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            ScopesType theScopes;
            theScopes = this.getScopes();
            if (this.scopes!= null) {
                currentHashCode += theScopes.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<String> theXAddrs;
            theXAddrs = (((this.xAddrs!= null)&&(!this.xAddrs.isEmpty()))?this.getXAddrs():null);
            if ((this.xAddrs!= null)&&(!this.xAddrs.isEmpty())) {
                currentHashCode += theXAddrs.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            long theMetadataVersion;
            theMetadataVersion = this.getMetadataVersion();
            currentHashCode += ((int)(theMetadataVersion^(theMetadataVersion >>> 32)));
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            EndpointReferenceType theEndpointReference;
            theEndpointReference = this.getEndpointReference();
            strategy.appendField(locator, this, "endpointReference", buffer, theEndpointReference, (this.endpointReference!= null));
        }
        {
            List<QName> theTypes;
            theTypes = (((this.types!= null)&&(!this.types.isEmpty()))?this.getTypes():null);
            strategy.appendField(locator, this, "types", buffer, theTypes, ((this.types!= null)&&(!this.types.isEmpty())));
        }
        {
            ScopesType theScopes;
            theScopes = this.getScopes();
            strategy.appendField(locator, this, "scopes", buffer, theScopes, (this.scopes!= null));
        }
        {
            List<String> theXAddrs;
            theXAddrs = (((this.xAddrs!= null)&&(!this.xAddrs.isEmpty()))?this.getXAddrs():null);
            strategy.appendField(locator, this, "xAddrs", buffer, theXAddrs, ((this.xAddrs!= null)&&(!this.xAddrs.isEmpty())));
        }
        {
            long theMetadataVersion;
            theMetadataVersion = this.getMetadataVersion();
            strategy.appendField(locator, this, "metadataVersion", buffer, theMetadataVersion, true);
        }
        {
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

}
